from distutils.core import setup
setup(
  name = 'pythloghlp',
  packages = ['pythloghlp'], # this must be the same as the name above
  version = '0.1.11',
  description = 'Python DynamoDB Log Helper',
  author = 'Gunder Biten',
  author_email = 'gunder.biten@gabcia.se',
  url = 'https://github.com/Immunovia-AB/PythLogHlp', # use the URL to the github repo
  download_url = 'https://github.com/Immunovia-AB/PythLogHlp/tarball/0.1', # I'll explain this in a second
  keywords = ['logging', 'DynamoDB'], # arbitrary keywords
  classifiers=[]
)